@@ -5,16 +5,17 @@
 #' presence or absence of a collective anomaly across the components. It uses Circular Binary Segmentation to detect multiple collective anomalies.
 #' 
 #' 
-#' @param x An n x m real matrix representing n observations of m variates.
+#' @param x An n x p real matrix representing n observations of p variates.
 #' @param alpha A positive integer > 0. This value is used to stabilise the higher criticism based test statistic used by PASS leading to a better finite sample familywise error rate. 
 #' Anomalies affecting fewer than alpha components will however in all likelihood escape detection.
 #' @param lambda A positive real value setting the threshold value for the familywise Type 1 error. The default value
-#' is \eqn{(1.1 {\rm log}(n \times Lmax) +2 {\rm log}({\rm log}(m))) / \sqrt{{\rm log}({\rm log}(m))}}. 
-#' @param Lmax A positive integer (\code{Lmax} > 0) corresponding to the maximum segment length. The default value is 10.
-#' @param Lmin A positive integer (\code{Lmax} >= \code{Lmin} > 0) corresponding to the minimum segment length. The default value is 1. 
+#' is \eqn{(1.1 {\rm log}(n \times max\_seg\_len) +2 {\rm log}({\rm log}(p))) / \sqrt{{\rm log}({\rm log}(p))}}. 
+#' @param max_seg_len A positive integer (\code{max_seg_len} > 0) corresponding to the maximum segment length. This parameter corresponds to Lmax in Jeng et al. (2012). The default value is 10. 
+#' @param min_seg_len A positive integer (\code{max_seg_len} >= \code{min_seg_len} > 0) corresponding to the minimum segment length. This parameter corresponds to Lmin in Jeng et al. (2012).
+#' The default value is 1. 
 #' @param transform A function used to transform the data prior to analysis. The default value is to scale the data using the median and the median absolute deviation.
 #'
-#' @return An S4 object of type \code{.pass.class} containing the data \code{X}, procedure parameter values, and the results.
+#' @return An instance of an S4 object of type \code{.pass.class} containing the data \code{X}, procedure parameter values, and the results.
 #' 
 #' @references \insertRef{10.1093/biomet/ass059}{anomaly}
 #' 
@@ -22,7 +23,7 @@
 #' library(anomaly)
 #' # generate some multivariate data
 #' set.seed(0)
-#' sim.data<-simulate(n=500,p=200,mu=2,locations=c(100,200,300),
+#' sim.data<-simulate(n=500,p=100,mu=2,locations=c(100,200,300),
 #'                    duration=6,proportions=c(0.04,0.06,0.08))
 #' res<-pass(sim.data)
 #' summary(res)
@@ -30,8 +31,11 @@
 #'
 #' @export
 
-pass<-function(x,alpha=2,lambda=NULL,Lmax=10,Lmin=1,transform=robustscale)
+pass<-function(x,alpha=2,lambda=NULL,max_seg_len=10,min_seg_len=1,transform=robustscale)
 {
+    # reflect renamed variable
+    Lmax = max_seg_len
+    Lmin = min_seg_len
     # check the data
     x<-as.array(as.matrix(x))
     if(!is_array(x))
@@ -50,41 +54,62 @@ pass<-function(x,alpha=2,lambda=NULL,Lmax=10,Lmin=1,transform=robustscale)
     {
         stop("x must be of type numeric")
     }        
+    if(any(is.infinite(x)))
+    {
+      stop("x contains Inf values")
+    }
+    if(!is_function(transform))
+    {
+      stop("transform must be a function")
+    }
     # transform data
     Xi<-transform(x)
     # check dimensions,types and values
-    if(!(is_whole_number(Lmax) && is_positive(Lmax)))
+    if(!check.alpha(Lmax))
     {
-        stop("Lmax must be a positive whole number")
+        stop("max_seg_len must be a positive integer")
     }
-    if(!(is_whole_number(Lmax) && is_positive(Lmax)))
+    if(!check.alpha(Lmin))
     {
-        stop("Lmin must be a positive whole number")
+        stop("min_seg_len must be a positive integer")
     }
-    if(!is_positive(Lmax-Lmin))
+    if(!(Lmax >= Lmin))
     {
-        stop("Lmax must be greater than Lmin")
+        stop("max_seg_len must be greater than min_seg_len")
     }
-    if(!(is_whole_number(alpha) && is_non_negative(alpha)))
+    if(!check.alpha(alpha))
     {
-        stop("alpha must be a non-negative whole number")
+        stop("alpha must be a positive integer")
+    }
+    ## LB ADDED - if number of variates < default alpha (2) -> alpha = 1
+    if(dim(x)[2] < alpha){
+      alpha = 1
     }
     if(is.null(lambda))
     {
-        n_rows<-dim(x)[1]
-        n_cols<-dim(x)[2]
+      n_rows<-dim(x)[1]
+      n_cols<-dim(x)[2]
+      if (n_cols < 3){
+        lambda <- 10
+        message = paste("The data has only N =", n_cols, "variates.", "Since the value of",  "\U03BB", "is based on asymptotic theory as the number of variates, N tends to infinity we suggest using simulations to determine a data-driven threshold to control the number of overselections. A default value of", "\U03BB = 10 has been used here.")
+        warning(message)
+      }
+      else{
         lambda<-(3.0*log(n_rows*Lmax) + 2*log(log(n_cols)))/sqrt(2*log(log(n_cols)))
+      }
     }
-    if(!(is_numeric(lambda) && is_positive(lambda)))
-    {
-        stop("lambda must be numeric value greater than 0")
+    else{
+      if(!check.lambda(lambda))
+      {
+        stop("lambda must be a positive real number")
+      }
     }
     assert_is_matrix(Xi)
     assert_is_non_empty(Xi)
     assert_all_are_real(Xi)
     if(!is_positive(nrow(Xi) - Lmax))
     {
-        stop("number of rows (observations) in Xi must be greater than Lmax") 
+        stop("number of rows (observations) in X must be greater than max_seg_len") 
     }
     # if the columns (variates) do not have names - give them default ones
     if(!has_colnames(Xi))
@@ -96,12 +121,14 @@ pass<-function(x,alpha=2,lambda=NULL,Lmax=10,Lmin=1,transform=robustscale)
     {
         marshall_pass(Map(function(j) unlist(Xi[,j]),1:ncol(Xi)),Lmax,Lmin,alpha,lambda)
     },
-    error = function(e) {e$message<-"pass stopped because of user interrupt";print(e$message);stop();}
+    error = function(e) {print(e$message);stop();}
     )
     # post process results
     if(length(pass.results) == 0) # no anomalies
     {
-        results<-data.frame(NA,NA,NA)
+        results<-data.frame("start"=integer(0), "end"=integer(0), "xstar"=integer(0))
+        results.S4<-pass.class(Xi,results,Lmax,Lmin,alpha,lambda)
+        return(results.S4)
     }
     else
     {
@@ -120,3 +147,18 @@ pass<-function(x,alpha=2,lambda=NULL,Lmax=10,Lmin=1,transform=robustscale)
     #results.S4<-pass.class(Xi,results,Lmax,Lmin,alpha,lambda)
     #return(results.S4)
 }
+
+
+check.alpha = function(input){
+  
+  res = (length(input) == 1) && (is.numeric(input)) && (!is.nan(input)) && (input > 0) && (!is.infinite(input)) && (input%%1 == 0)
+  return(res)
+  
+}
+
+check.lambda = function(input){
+  
+  res = (length(input) == 1) && (is.numeric(input)) && (!is.nan(input)) && (input > 0)
+  return(res)
+  
+}
\ No newline at end of file
