@@ -22,7 +22,8 @@ std::vector<int> MeanAnomalyMV(SEXP Rx, SEXP Rn, SEXP Rp, SEXP Rl, SEXP Rminleng
   Rx    : Data
   Rn    : Length of data
   */
-	 
+
+  /*
  	PROTECT(Rx) ; 
  	PROTECT(Rn) ;
  	PROTECT(Rp) ;
@@ -32,7 +33,7 @@ std::vector<int> MeanAnomalyMV(SEXP Rx, SEXP Rn, SEXP Rp, SEXP Rl, SEXP Rminleng
 	PROTECT(Rbetaanomaly) ;
 	PROTECT(Rmaxlength) ;
 	PROTECT(Ronline) ;
-	
+  */	
   	int n = 0, p = 0, l = 0, minlength = 0, ii = 0, error = 0, maxlength = 0, online = 0;
   	double betaanomaly = 0.0;
   	double* x = NULL;
@@ -51,7 +52,7 @@ std::vector<int> MeanAnomalyMV(SEXP Rx, SEXP Rn, SEXP Rp, SEXP Rl, SEXP Rminleng
 
 	std::vector<int> vout;	
 	std::string reason;
-	int *out;
+	// int *out;
 	struct orderedobservationlist_mean* mylist;
 
 
@@ -173,7 +174,7 @@ clearup:
 
 	if(betachange){ delete[] betachange;}
 
-  	UNPROTECT(9);
+	//  	UNPROTECT(9);
 
 	if (error != 0)
 	{
